@@ -14,6 +14,7 @@ from datetime import datetime
 from decimal import Decimal
 import itertools
 import hashlib
+import sys
 
 import redis
 
@@ -22,6 +23,9 @@ from blingalytics.utils.serialize import encode, encode_dict, decode, \
     decode_dict
 
 
+REDIS_MAX_INT = long(-sys.float_info.max)
+
+
 class RedisCache(caches.Cache):
     """
     Caches computed reports in Redis. This takes the same init options as the
@@ -38,7 +42,7 @@ class RedisCache(caches.Cache):
     def __init__(self, **kwargs):
         """
         Accepts the same arguments as redis-py client.
-        
+
         Defaults to localhost:6379 and database 0.
         """
         self.conn_kwargs = kwargs
@@ -98,6 +102,8 @@ class RedisCache(caches.Cache):
                     data[name] = float(value)
                 elif t in (int, float, long, str):
                     data[name] = value
+                elif t is type(None):
+                    data[name] = REDIS_MAX_INT  # For sorting
                 else:
                     data[name] = str(value)
             p.hmset(key, data)
@@ -159,8 +165,9 @@ class RedisCache(caches.Cache):
 
     def instance_timestamp(self, report_id, instance_id):
         table_name = '%s:%s' % (report_id, instance_id)
-        timestamp = self.conn['%s:' % table_name]
-        if not timestamp:
+        try:
+            timestamp = self.conn['%s:' % table_name]
+        except KeyError:
             raise caches.InstanceIncompleteError
         return decode(timestamp)
 
