@@ -64,23 +64,23 @@ class Source(object):
     Subclasses should define any or all of the methods: pre_process, get_rows,
     and post_process. The report base class will call these methods at the
     appropriate times to retrieve and process the data from this source.
-    
+
     The pre_process method is called at the start of the get_rows call to the
     report instance. You can use this method to do any setup or processing to
     prepare for the get_rows call.
-    
+
     The get_rows method is called by the report instance on all its sources in
     tandem, and they are combined using Python's heapq implementation. See the
     get_rows docstring for a detailed explanation of how to emit the rows.
-    
+
     The post_process gives each source an opportunity to act on the row values
     as returned by itself and all the other sources. This provides an
     opportunity for the source to do calculations or adjustments based on the
     values returned by another source.
-    
+
     By default, the Source class stores the report's filters, key ranges, and
     columns, for reference within the source implementation:
-    
+
     * _filters: The filters list defined on the report.
     * _keys: The normalized list of key ranges on the report.
     * _report_columns: The list of columns defined on the report.
@@ -121,7 +121,7 @@ class Source(object):
     def pre_process(self, clean_inputs):
         """
         Hook for doing prep work for the source.
-        
+
         You can use this method to do any setup or processing to prepare for
         the get_rows call.
         """
@@ -130,33 +130,33 @@ class Source(object):
     def get_rows(self, key_rows, clean_inputs):
         """
         Returns an iterator over the row data from this source.
-        
+
         The formatting and order of the returned rows is hugely important. The
         report instance pulls the iterators for all its sources' get_rows in
         tandem, and combines them into rows using Python's heapq
-        implementation. 
-        
+        implementation.
+
         Rows should be returned as a tuple of key and partial row. The key is
         a tuple of the values of the report's key columns, in the order they
         are defined in report.keys. (Every source in a report is required to
         return the same keys.) The partial row is a dict of column name to
         value pairs. The rows must be returned in sorted order (by the key
         tuple). For example:
-        
+
         [
             ((12,), {'date': 12, 'total': 3}),
             ((14,), {'date': 14, 'total': 35}),
             ((15,), {'date': 15, 'total': 10}),
             ...
         ]
-        
+
         The get_rows method is passed the key_rows for the report, which are
         rows (formatted as above) that just contain the key columns. This can
         be useful if the source needs to act upon these values, for example to
         perform database lookups on the values. However, the report is not
         required to use these values and need not even emit a value for each
         key row.
-        
+
         It is also good practice to process the rows as incrementally as
         possible. Since we are often working with very large data sets, we
         don't want to pull the whole thing into memory all at once. Instead,
@@ -167,13 +167,13 @@ class Source(object):
 
     def post_process(self, row, clean_inputs):
         """
-        Hook for doing any post-processing work. 
-        
+        Hook for doing any post-processing work.
+
         This method is called once for each row in the report, once it has
         combined the results of the get_rows from each of the report's
         sources. It receives the row as a dict, and it should return the full
         row after it has made the desired updates.
-        
+
         This method allows for any processing work over the results from this
         and other sources. It should not, however, rely on the post_process
         work from any sources, as post_process is called in an indeterminate
@@ -184,9 +184,9 @@ class Source(object):
 class Filter(object):
     """
     Defines the base for filtering source data.
-    
+
     By default, filters take two optional arguments:
-    
+
     * columns: Can be a string, a list of strings, or None. If one or more
       strings are provided, the filter should be applied only to those columns
       in the report. If None is provided (the default) the filter should be
@@ -194,7 +194,7 @@ class Filter(object):
     * widget: A widget class or instance that defines the widget type the user
       should be shown to input a filter argument. This is optional, and
       defaults to None.
-    
+
     This base class, however, merely accepts these as standard filtering
     options. It is entirely up to the subclassed filter and source
     implementations to define the functionality of the columns and widgets.
@@ -212,15 +212,15 @@ class Filter(object):
 class Column(object):
     """
     Defines the base for defining a column of this source type.
-    
+
     Concrete subclasses are expected to set 'source' equal to their source
     class as an attribute on the column class. For example, for a database
     column would define the following line:
-    
-    source = SQLAlchemySource
-    
+
+    source = DjangoORMSource
+
     By default, columns handle two optional arguments:
-    
+
     * format: A format class or instance that should be used to determine the
       formatting and display options for this column. If none is provided (the
       default), the column is assumed to be hidden.
@@ -228,16 +228,16 @@ class Column(object):
       column. Column subclasses may also implement special-case strings for
       this option to provide any other sort of optional footer functionality.
       Defaults to True.
-    
+
     This base class, however, only implements basic format and footer
     handling. It is entirely up to the subclassed column and source
     implementations to define this column's specific functionality.
-    
+
     By default, a column's footer functionality is simply a sum for types that
     can be added, and blank for all other values. For int, long, Decimal, and
     float values, all the values returned from the source are totaled and
     returned for the footer.
-    
+
     To provide a specialized footer behavior for your column, you can override
     the increment_footer and finalize_footer methods, documented below.
     """
@@ -258,12 +258,12 @@ class Column(object):
     def increment_footer(self, total, cell):
         """
         Increments this column's footer total.
-        
+
         Receives the current total, which is either None the first time this
         is called for a report, or whatever value the method returned last
         time. Also receives the cell value for this column for the row
         currently being processed.
-        
+
         The method should return the new running total, incremented (using
         whatever method is appropriate) by the cell value.
         """
@@ -286,11 +286,11 @@ class Column(object):
     def finalize_footer(self, total, footer):
         """
         Finalizes and returns this column's footer total.
-        
+
         Receives the column's running total after increment_footer has been
         called for every row in the report. Also receives the entire footer's
         running totals as a dict.
-        
+
         This allows your footer to be calculated by using data from other
         columns' footers. Your method should return the finalized footer total
         for this column.
@@ -300,11 +300,11 @@ class Column(object):
 def normalize_key_ranges(init_key_ranges):
     """
     Utility function to normalize the keys given on a report definition.
-    
+
     The key range argument should be a list of two-tuples specifying each key.
     The first element of the two-tuple is a string for the key's column; the
     second element should be a KeyRange instance.
-    
+
     This attribute on a report is very permissive, though. The common case is
     to have just one key range for a report, so if you pass just the one
     two-tuple, it will automatically be wrapped in a list. You are also not
@@ -323,7 +323,7 @@ def normalize_key_ranges(init_key_ranges):
 class KeyRange(object):
     """
     Base class for key ranges.
-    
+
     Key ranges define the keyspace for a report. In other words, this defines
     what rows you want outputted for a report, and the data will be pulled and
     filled in for those rows.
@@ -344,12 +344,12 @@ class KeyRange(object):
     def get_row_keys(self, clean_inputs):
         """
         Returns an iterable of keys guaranteed for the report.
-        
+
         This method is given the list of widgets from the report, from which
         it can pull user inputs for use in determining the key range. For
         example, a date key range could use start and end date widgets and
         return a key for each day in that range.
-        
+
         Note that key ranges are not restrictive. That is, the keys returned
         by the key range guarantee that such a row will appear in the report
         output; however, a report may return more key values than defined in
